Welcome to Whalrus' documentation!
==================================

.. figure:: whalrus.png
   :scale: 75 %
   :alt: whalrus' logo
   :align: center

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   tutorial
   reference
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
